@@ -13,8 +13,8 @@ from valuebag import ValueBag
 
 __all__ = ['settings', 'version']
 
-def expand_path(path):
-    return realpath(expandvars(expanduser(path)))
+#def expand_path(path):
+#    return realpath(expandvars(expanduser(path)))
   
 class GlobalSettings(ValueBag):
     def __init__(self, d = {}):
@@ -32,10 +32,8 @@ class GlobalSettings(ValueBag):
             if mod:
                 for key in dir(mod):
                     if key == key.upper():
-                        v = getattr(mod, key)
-                        if isinstance(v, (str, unicode)):
-                            v = expand_path(v)
-                        setattr(self, key, v)
+                        #v = getattr(mod, key)
+                        setattr(self, key, getattr(mod, key))
                 
 
 settings = GlobalSettings({
@@ -49,9 +47,9 @@ settings = GlobalSettings({
                            'ENV_PIDFILE'        : 'OPT_PIDFILE'
                            })
 
-settings.ROOT_DIR = expand_path('$VIRTUAL_ENV/..')
+settings.ROOT_DIR = '$VIRTUAL_ENV/..'  # expand_path('$VIRTUAL_ENV/..')
 if os.environ.has_key('OPT_SITE_DIR'):
-    settings.SITE_DIR = expand_path(os.environ['OPT_SITE_DIR'])
+    settings.SITE_DIR = os.environ['OPT_SITE_DIR'] # expand_path(os.environ['OPT_SITE_DIR'])
 else:
     settings.SITE_DIR = join(settings.ROOT_DIR, 'site')
 settings.DATA_DIR = join(settings.SITE_DIR, 'data')
