@@ -29,6 +29,15 @@ class ValueBag(dict):
             self[name] = value
                         
     def __setitem__(self, name, value):
+        if '.' in name:
+            names = name.split('.')
+            s = self
+            for name in names[:-1]:
+                s = s[name]
+            name = names[-1]
+        else:
+            s = self
+
         if name == name.upper():
             if isinstance(value, (str, unicode)):
                 value = os.path.expanduser(value)
@@ -40,12 +49,19 @@ class ValueBag(dict):
         elif isinstance(value, dict):
             value = ValueBag(value)
 
-        super(ValueBag, self).__setitem__(name, value)
+        super(ValueBag, s).__setitem__(name, value)
         
     def __getattr__(self, name):
         return self[name]
     
     def __getitem__(self, name):
+        if '.' in name:
+            s = self
+            for name in name.split('.'):
+                s = s[name]
+            return s
+
+
         if self.has_key(name):
             return self.get(name)
         
